svn commit: r14960 - trunk/src/argouml-app/src/org/argouml: application notation/providers/uml ui uml/diagram/static_structure/ui uml/reveng

[email protected]
Newsgroups gmane.comp.lang.uml.argouml.cvs
Message-ID <[email protected]>
Author: mvw
Date: 2008-06-16 09:36:10-0700
New Revision: 14960

Modified:
   trunk/src/argouml-app/src/org/argouml/application/Main.java
   trunk/src/argouml-app/src/org/argouml/notation/providers/uml/NotationUtilityUml.java
   trunk/src/argouml-app/src/org/argouml/ui/DetailsPane.java
   trunk/src/argouml-app/src/org/argouml/uml/diagram/static_structure/ui/FigClassifierBoxWithAttributes.java
   trunk/src/argouml-app/src/org/argouml/uml/reveng/Import.java

Log:
Style.

Modified: trunk/src/argouml-app/src/org/argouml/application/Main.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-app/src/org/argouml/application/Main.java?view=diff&rev=14960&p1=trunk/src/argouml-app/src/org/argouml/application/Main.java&p2=trunk/src/argouml-app/src/org/argouml/application/Main.java&r1=14959&r2=14960
==============================================================================
--- trunk/src/argouml-app/src/org/argouml/notation/providers/uml/NotationUtilityUml.java	(original)
+++ trunk/src/argouml-app/src/org/argouml/notation/providers/uml/NotationUtilityUml.java	2008-06-16 09:36:10-0700
@@ -375,7 +375,7 @@
             Object nspe =
                 Model.getModelManagementHelper().getElement(
                         path,
-                        Model.getFacade().getModel(me));
+                        Model.getFacade().getRoot(me));
 
             if (nspe == null || !(Model.getFacade().isANamespace(nspe))) {
                 String msg = 
@@ -509,7 +509,7 @@
         // Copy returned parameters because it will be a live collection for MDR
         Collection origParam =
             new ArrayList(Model.getFacade().getParameters(op));
-        Object ns = Model.getFacade().getModel(op);
+        Object ns = Model.getFacade().getRoot(op);
         if (Model.getFacade().isAOperation(op)) {
             Object ow = Model.getFacade().getOwner(op);
 
@@ -811,7 +811,7 @@
 
         /**
          * Constructs a new PropertySpecialString that will invoke the
-         * action in op when {@link #invoke(Object, String, String)} is
+         * action in propop when {@link #invoke(Object, String, String)} is
          * called with name equal to str and then return true from invoke.
          *
          * @param str
@@ -825,8 +825,9 @@
         }
 
         /**
-         * Called by {@link ParserDisplay#setProperties(Object, java.util.Vector,
-         * PropertySpecialString[])} while searching for an action to
+         * Called by {@link NotationUtilityUml#setProperties(Object, 
+         * java.util.Vector, PropertySpecialString[])} while 
+         * searching for an action to
          * invoke for a property. If it returns true, then setProperties
          * may assume that all required actions have been taken and stop
          * searching.
@@ -835,10 +836,12 @@
          *            The name of a property.
          * @param value
          *            The value of a property.
+         * @param element
+         *            A model element to apply the properties to.
          * @return <code>true</code> if an action is performed, otherwise
          *         <code>false</code>.
          */
-        public boolean invoke(Object element, String pname, String value) {
+        boolean invoke(Object element, String pname, String value) {
             if (!name.equalsIgnoreCase(pname)) {
                 return false;
             }
@@ -945,6 +948,15 @@
         return "";
     }
 
+    /**
+     * Create a string representation of a single stereotype.
+     * This function generates angled brackets or guillemets 
+     * depending in the project's settings.
+     * 
+     * @param name the name of the stereotype
+     * @param args any arguments
+     * @return the string representation
+     */
     public static String formatSingleStereotype(String name, Map args) {
         if (name == null || name.length() == 0) {
             return "";
@@ -969,6 +981,7 @@
      * with the arguments Map.
      * Rationale: Use the args Map instead of accessing the Project from here.
      */
+    @Deprecated
     public static String generateStereotype(Object st) {
         if (st == null) {
             return "";
@@ -1113,6 +1126,7 @@
      * @param m the given multiplicity
      * @return a string (guaranteed not null)
      */
+    @Deprecated
     public static String generateMultiplicity(Object m) {
         Project p = ProjectManager.getManager().getCurrentProject();
         ProjectSettings ps = p.getProjectSettings();
@@ -1146,7 +1160,7 @@
         }
         if (!NotationProvider.isValue("singularMultiplicityVisible", args)) {
             if ("1".equals(s)) {
-                s =""; 
+                s = ""; 
             }
         }
         return s;
@@ -1186,7 +1200,8 @@
                 }
 
                 if (Model.getFacade().getValue(arg) != null) {
-                    p.append(generateExpression(Model.getFacade().getValue(arg)));
+                    p.append(generateExpression(
+                            Model.getFacade().getValue(arg)));
                 }
                 first = false;
             }

Modified: trunk/src/argouml-app/src/org/argouml/ui/DetailsPane.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-app/src/org/argouml/ui/DetailsPane.java?view=diff&rev=14960&p1=trunk/src/argouml-app/src/org/argouml/ui/DetailsPane.java&p2=trunk/src/argouml-app/src/org/argouml/ui/DetailsPane.java&r1=14959&r2=14960
==============================================================================
--- trunk/src/argouml-app/src/org/argouml/ui/DetailsPane.java	(original)
+++ trunk/src/argouml-app/src/org/argouml/ui/DetailsPane.java	2008-06-16 09:36:10-0700
@@ -574,11 +574,11 @@
     /*
      * @see org.tigris.swidgets.Orientable#setOrientation(org.tigris.swidgets.Orientation)
      */
-    public void setOrientation(Orientation orientation) {
+    public void setOrientation(Orientation newOrientation) {
         for (JPanel t : tabPanelList) {
             if (t instanceof Orientable) {
                 Orientable o = (Orientable) t;
-                o.setOrientation(orientation);
+                o.setOrientation(newOrientation);
             }
         }
     }

Modified: trunk/src/argouml-app/src/org/argouml/uml/diagram/static_structure/ui/FigClassifierBoxWithAttributes.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-app/src/org/argouml/uml/diagram/static_structure/ui/FigClassifierBoxWithAttributes.java?view=diff&rev=14960&p1=trunk/src/argouml-app/src/org/argouml/uml/diagram/static_structure/ui/FigClassifierBoxWithAttributes.java&p2=trunk/src/argouml-app/src/org/argouml/uml/diagram/static_structure/ui/FigClassifierBoxWithAttributes.java&r1=14959&r2=14960
==============================================================================
--- trunk/src/argouml-app/src/org/argouml/uml/diagram/static_structure/ui/FigClassifierBoxWithAttributes.java	(original)
+++ trunk/src/argouml-app/src/org/argouml/uml/diagram/static_structure/ui/FigClassifierBoxWithAttributes.java	2008-06-16 09:36:10-0700
@@ -347,8 +347,9 @@
         getNameFig().setBounds(x, y + currentHeight, w, nameHeight);

         currentHeight += nameHeight;

 

-        if (attributesFigCompartment.isVisible()){

-            int attributesHeight = attributesFigCompartment.getMinimumSize().height;

+        if (attributesFigCompartment.isVisible()) {

+            int attributesHeight = 

+                attributesFigCompartment.getMinimumSize().height;

             if (isOperationsVisible()) {

                 attributesHeight += whitespace / 2;

             }


Modified: trunk/src/argouml-app/src/org/argouml/uml/reveng/Import.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-app/src/org/argouml/uml/reveng/Import.java?view=diff&rev=14960&p1=trunk/src/argouml-app/src/org/argouml/uml/reveng/Import.java&p2=trunk/src/argouml-app/src/org/argouml/uml/reveng/Import.java&r1=14959&r2=14960
==============================================================================
--- trunk/src/argouml-app/src/org/argouml/uml/reveng/Import.java	(original)
+++ trunk/src/argouml-app/src/org/argouml/uml/reveng/Import.java	2008-06-16 09:36:10-0700
@@ -259,9 +259,8 @@
                     .localize("action.import-option-min-class-icon"), mini);
             general.add(minimiseFigs);
 
-            layoutDiagrams = new JCheckBox(
-                    Translator
-                            .localize("action.import-option-perform-auto-diagram-layout"),
+            layoutDiagrams = new JCheckBox(Translator.localize(
+                    "action.import-option-perform-auto-diagram-layout"),
                     layo);
             general.add(layoutDiagrams);
 
@@ -579,7 +578,7 @@
             File[] files = getSelectedFiles();
             File dir = getCurrentDirectory();
             if (files.length == 0) {
-                files = new File[] { dir };
+                files = new File[] {dir };
             }
             if (files.length == 1) {
                 File file = files[0];
@@ -593,9 +592,10 @@
             Globals.setLastDirectory(dir.getPath());
             theImport.disposeDialog();
 
-            if (theImport.getCurrentModule() instanceof ExtendedImportInterface) {
-                ExtendedImportInterface eii = (ExtendedImportInterface) theImport
-                        .getCurrentModule();
+            if (theImport.getCurrentModule() 
+                    instanceof ExtendedImportInterface) {
+                ExtendedImportInterface eii = 
+                    (ExtendedImportInterface) theImport.getCurrentModule();
                 eii.invokeImport(new ImportCommand(theImport));
             } else {
                 theImport.doFile();
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
--- trunk/src/argouml-app/src/org/argouml/application/Main.java	(original)
+++ trunk/src/argouml-app/src/org/argouml/application/Main.java	2008-06-16 09:36:10-0700
@@ -538,12 +538,12 @@
      * If the file does not exist or cannot be converted the default
      * {@link URL} is returned.
      *
      * @param projectName is the file name of the project
      * @param urlToOpen is the default {@link URL}
      * @return the new URL.
      */
-    private static URL projectUrl(final String projectName, URL urlToOpen) {
-        File projectFile = new File(projectName);
+    private static URL projectUrl(final String theProjectName, URL urlToOpen) {
+        File projectFile = new File(theProjectName);
         if (!projectFile.exists()) {
             System.err.println("Project file '" + projectFile
 			       + "' does not exist.");
@@ -538,12 +538,12 @@
      * {@link URL} is returned.
      *
-     * @param projectName is the file name of the project
+     * @param theProjectName is the file name of the project
      * @param urlToOpen is the default {@link URL}
      * @return the new URL.

Modified: trunk/src/argouml-app/src/org/argouml/notation/providers/uml/NotationUtilityUml.java
Url: http://argouml.tigris.org/source/browse/argouml/trunk/src/argouml-app/src/org/argouml/notation/providers/uml/NotationUtilityUml.java?view=diff&rev=14960&p1=trunk/src/argouml-app/src/org/argouml/notation/providers/uml/NotationUtilityUml.java&p2=trunk/src/argouml-app/src/org/argouml/notation/providers/uml/NotationUtilityUml.java&r1=14959&r2=14960
==============================================================================